; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;   buffer.time = time (optional...Linux/WinM.U.G.E.N only)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;                                  ;(Linux/WinM.U.G.E.N only)
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; - buffer.time (optional...Linux/WinM.U.G.E.N only)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
; (Linux/WinM.U.G.E.N only)
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; (Linux/WinM.U.G.E.N only)
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| AI |-------------------------------------------------------------------
; These 11 Single Button and Hold Dir commands must be placed here at the top
; of the CMD, above all other commands, and in the standard order shown here,
; in order for the "Compatibly Partnered" version (9742) of the helper AI
; activation method to work with different partners in simul team mode.
; (When the partner is not compatible, then it's best to just use the regular
; version (9741) and rely on the XOR method for backup in case a human
; partner's input turns off the CPU partner's AI.)
; (Now, even if you do not intend to give your character any custom AI, it
; would still be nice if you would place the commands at the top of your CMD,
; for the sake of other characters which do use this AI activation method.
; And then, define Anim 9741 in your AIR file to indicate to other characters
; that your character is compatible.
; It may slightly increase the chances of faulty AI activation if the user is
; using characters with a poor implementation of the old humanly-impossible
; commands AI activation method when fighting against your character, but
; other than that, there's really no particular reason not to.  And you can
; change the names of the commands if you want.  For compatibility, all that
; really matters is the "command" and "time" parameters.)
;
; Another important point to make, is that if you want to add additional
; definitions for any of these basic command names, then there are limits on
; what kind of parameters you can use, in order to ensure the reliability of
; the helper method.  That is, if you redefine any of these first 11 commands,
; then you must follow these rules when doing so:
; - Don't use any command string that includes any tildes. (e.g. no "~x",
;   no "~30D")
; - In the command string, don't include any direction that isn't preceeded by
;   a slash. (e.g. no "F", no "$D")
; - Don't put any non-slashed buttons in a command string overloading one of
;   the Hold Dir command names.
; - Using a command string that includes any commas (e.g. no "a,b"), and/or
;   setting the time parameter to greater than 1, may be safe, but I wouldn't
;   risk it.
; An example of what is permissible, is redefining the "z" button like so:
;	[Command]
;	name = "z"
;	command = y+b
;	time = 1
; Other than that particular common type of redefinition, it's probably best
; to simply avoid adding definitions for these 11 command names altogether.
; And remember, this paragraph just has to do with the helper method.  You'll
; still need to make changes to the XOR code, no matter what type of overloading
; you use with the commands used by it.
;
;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |----------------------------------------------------------
; Please define Anim 74140108 in your AIR file if AND ONLY IF you place these
; 7 Hold Button commands immediately after the 11 Single Button and Hold Dir
; commands at the very top of your CMD list, as demonstrated here.
; In this version of the AI code, these commands are only used by the XOR
; method, and thus are optional.  But there remains a possibility that a
; future version of the helper method might be helped by having these
; commands placed here, and Anim 74140108 would then be used to indicate
; that a partner character has a compatible CMD.

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

;-| CPU |--------------------------------------------------------------
; Note that if you make any changes to the basic one-button or recovery
; commands, you'll need to make the same changes to their matching commands here
; and/or in the XOR VarSet controller.  That includes things like, for example:
;  * changing the recovery command to use a different combination of buttons.
;  * renaming the b button command as "d", or the start button command as "s".
;  * switching the button names around, e.g. so button y triggers "a" and button a triggers "y".
;  * having more than one way to trigger the same command name.
; If you understand how the XOR method works, the proper changes should be obvious.
; If you don't understand it, then simply disable the lines in the XOR VarSet
; controller that correspond to the commands you've altered.

[Command]
name = "a2"
command = a
time = 1

[Command]
name = "b2"
command = b
time = 1

[Command]
name = "c2"
command = c
time = 1

[Command]
name = "x2"
command = x
time = 1

[Command]
name = "y2"
command = y
time = 1

[Command]
name = "z2"
command = z
time = 1

[Command]
name = "start2"
command = s
time = 1

[Command]
name = "holdfwd2"
command = /$F
time = 1

[Command]
name = "holdback2"
command = /$B
time = 1

[Command]
name = "holdup2"
command = /$U
time = 1

[Command]
name = "holddown2"
command = /$D
time = 1

[Command]
name = "holda2"
command = /a
time = 1

[Command]
name = "holdb2"
command = /b
time = 1

[Command]
name = "holdc2"
command = /c
time = 1

[Command]
name = "holdx2"
command = /x
time = 1

[Command]
name = "holdy2"
command = /y
time = 1

[Command]
name = "holdz2"
command = /z
time = 1

[Command]
name = "holdstart2"
command = /s
time = 1

[Command]
name = "recovery2"
command = x+y
time = 1

; Here add matching commands for any moves that must never be used randomly
; by the computer, such as suicide moves and super moves, and add the pairs
; to the XOR VarSet controller in State -3.

; If you're desperate to make sure that the AI always gets turned on as soon
; as possible, you can add more equivalents for your own commands here too,
; and add to the XOR VarSet controller's triggers accordingly.  You should
; use button-only commands before using any commands with directional
; components, as the latter apparently doesn't work in Linux Mugen 2002.04.14.

; And of course, if you've run out of unique command labels (Mugen allows
; 128), you can remove as many of these as you want.  You'll of course need
; to modify the XOR VarSet controller's triggers accordingly, but Mugen
; will let you know if you forget to do so. :)

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

;-| Special Motions |------------------------------------------------------
[Command]
name = "up"
command = U
time = 1

[Command]
name = "up"
command = UB
time = 1

[Command]
name = "up"
command = UF
time = 1

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "MachineBite"
command = ~x, a, x
time = 20

[Command]
name = "MachineBite"
command = ~a, x, a
time = 20

[Command]
name = "Somerflip" ;Required (do not remove)
command = /$U,a
time = 1

[Command]
name = "guard"
command = /b
time = 1

[Command]
name = "dash"
command = b
time = 1

[Command]
name = "EnergyBall"
command = x+a
time = 1

[Command]
name = "charge"
command = /a
time = 1

[Command]
name = "charge2"
command = /x
time = 1

[Command]
name = "anydir"
command = /$F
time = 1

[Command]
name = "anydir"
command = /$B
time = 1

[Command]
name = "anydir"
command = /$U
time = 1

[Command]
name = "anydir"
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

; The main purpose of having these next two controllers here at the top of
; StateDef -1 is to make sure the AI helper never changes to a different state,
; but they also improve efficiency by preventing Mugen from wasting time
; processing the entire State -1 for the helper.
[State -1, AI Helper Check]
type = ChangeState
trigger1 = IsHelper(9741)
value = 9741

[State -1, AI Helper Check 2]
type = ChangeState
trigger1 = IsHelper(9742)
value = 9742

; This is generally the best place to put most of your AI directives.  For
; example, this controller would only be executed when the CPU is in control:
;
; [State -1, Haha!]
; type = ChangeState
; trigger1 = var(0) ; (Or use "var(59)>0" if you've chosen not to
;                   ; use the Simplifier variable/controller.)
; trigger1 = ctrl
; trigger1 = (StateType = S)
; trigger1 = (MoveType = I)
; trigger1 = (P2MoveType = H)
; trigger1 = (NumEnemy = 1)
; trigger1 = (Enemy,GetHitVar(HitTime) > 60)
; trigger1 = (PrevStateNo != 195)
; trigger1 = (Random < 99)
; value = 195

; And of course, most human-only command-based ChangeStates also belong
; in State -1.  For example, this move would only be performable by a human:
;
; [State -1, Death Before Dishonor]
; type = ChangeState
; trigger1 = (command = "suicide")
; trigger1 = !var(0) ; (Or use "var(59)<1" if you've chosen not to
;                    ; use the Simplifier variable/controller.)
; trigger1 = ctrl
; trigger1 = (StateType != A)
; trigger1 = (MoveType = I)
; value = {suicide state number}

;===========================================================================
;AI
;---------------------------------------------------------------------------


[State -1, Considerator Reset]
type = VarSet
trigger1 = 1
var(52) = 0

[State -1, OhMy]
type = VarSet
var(52) = 101+random%3
triggerall = var(59)>0
triggerall = ctrl && statetype = A
triggerall = numenemy
trigger1 = pos y < -240
trigger2 = p2dist y >= 20- ((enemynear,const(size.head.pos.y)) / ifelse(p2statetype=C,2,1))
trigger2 = enemynear,facing != facing
trigger2 = inguarddist

[State -1, Dashit]
type = VarSet
var(52) = 100
triggerall = var(59)>0
triggerall = ctrl && statetype = A
triggerall = random < 64
triggerall = prevstateno != 100
triggerall = stateno != 100
trigger1 = command = "holddown"
trigger1 = p2dist y >= 20- ((enemynear,const(size.head.pos.y)) / ifelse(p2statetype=C,2,1))
trigger2 = command = "holdup"
trigger2 = p2dist y <= -20

[State -1, Pissed off?]
type = VarSet
var(52) = 1100
triggerall = var(59)>0
triggerall = ctrl && statetype = A
triggerall = (life <= lifemax/4) || (random < 32)
triggerall = numhelper(1100) = 0
trigger1 = random < 110
trigger1 = p2dist x >= 120
trigger1 = p2dist y = [-20 ,20- ((enemynear,const(size.head.pos.y)) / ifelse(p2statetype=C,2,1)) ]

[State -1, Pissed off?]
type = VarSet
var(52) = 1000
triggerall = var(59)>0
triggerall = statetype = A
triggerall = random < 300
triggerall = (life <= lifemax/4) || (random < 32)
trigger1 = stateno = 200 || stateno = 210
trigger1 = movecontact

[State -1, *burp*]
type = VarSet
var(52) = ifelse(random<500,103,195)
triggerall = var(59)>0
triggerall = ctrl && statetype = A
triggerall = random < 100
triggerall = prevstateno != 195
trigger1 = p2stateno = [5100,5120]
trigger2 = p2dist x = [-10,10]

;[State -1, Attack]
;type = VarSet
;var(52) = 200 + ((random%3)*10)
;triggerall = numenemy
;triggerall = var(59)>0
;triggerall = ctrl && statetype = A
;trigger1 = random < 500
;trigger1 = p2dist x = [-25,120]
;trigger1 = p2dist y = [-20 ,20- ((enemynear,const(size.head.pos.y)) / ifelse(p2statetype=C,2,1)) ]

[State AI, Consider Attack 1]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80
triggerall = var(59)>0
triggerall = random < 500
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,60]
triggerall = p2dist y = [-10 ,10- ((enemynear,const(size.head.pos.y)) / ifelse(p2statetype=C,2,1)) ]
triggerall = statetype = A
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl || stateno = 100
var(52) = 200
ignorehitpause = 1

[State AI, Consider Sommersault]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80
triggerall = var(59)>0
triggerall = random < 173
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 100)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-15,75]
triggerall = p2dist y = [-64 ,10- ((enemynear,const(size.head.pos.y)) / ifelse(p2statetype=C,2,1)) ]
triggerall = statetype = A
triggerall = prevstateno != 1200
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = (stateno = 200 && p2bodydist x >= 60) || (stateno = 210)
trigger2 = movehit
var(52) = 1200
ignorehitpause = 1

[State AI, Consider Attack 2]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80
triggerall = var(59)>0
triggerall = random < 94
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 100)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,100]
triggerall = p2dist y = [-10 ,20- ((enemynear,const(size.head.pos.y)) / ifelse(p2statetype=C,2,1)) ]
triggerall = statetype = A
triggerall = prevstateno != 210
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = stateno = 200
trigger2 = movehit && p2bodydist x >= 60
var(52) = 210
ignorehitpause = 1


[State AI, Consider Frenzy]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80
triggerall = var(59)>0
triggerall = random < 64
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 100)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-15,100]
triggerall = p2dist y = [-10 ,10- ((enemynear,const(size.head.pos.y)) / ifelse(p2statetype=C,2,1)) ]
triggerall = statetype = A
triggerall = prevstateno != 1000
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = (stateno = 200 && p2bodydist x >= 50) || (stateno = 210)
trigger2 = movecontact
var(52) = 1000
ignorehitpause = 1

[State AI, Consider Eating]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80 || numhelper(510)
triggerall = var(59)>0
triggerall = random < 213
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [-5,120]
triggerall = p2dist y = [-20 ,20- ((enemynear,const(size.head.pos.y)) / ifelse(p2statetype=C,2,1)) ]
triggerall = statetype = A
triggerall = prevstateno != 220
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl || stateno = 100
trigger2 = (stateno = 200 && moveguarded) || (stateno = 210 && moveguarded) || (stateno = 1200 && movehit)
var(52) = 220
ignorehitpause = 1

[State AI, Consider projectile]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80) && (var(52)!=[200,250]) && (var(52)!=[400,650]) )
triggerall = var(59)>0
triggerall = random < 64
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 97) || (statetype = A)
triggerall = p2stateno != [5080,5130]
;triggerall = p2dist y = [-20 ,20- ((enemynear,const(size.head.pos.y)) / ifelse(p2statetype=C,2,1)) ]
;triggerall = statetype != A
triggerall = p2bodydist x >= -5
triggerall = (enemynear,GetHitVar(hittime) >= 8 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = prevstateno != [1100,1160]
triggerall = !numhelper(1100)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl
trigger2 = (stateno = 200 && moveguarded) || (stateno = 210 && moveguarded)
var(52) = 1100
ignorehitpause = 1
[State AI, Consider holding]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80
triggerall = var(59)>0
triggerall = p2movetype != A
;triggerall = !numhelper(3050) || random < 500
triggerall = p2bodydist x >= 15
trigger1 = stateno = [1100,1160]
trigger1 = p2statetype != A || p2statetype = L
trigger1 = (enemynear, ctrl = 1 && p2bodydist x >= 80) || (p2statetype=L) || (p2stateno=[120,169]) || (p2stateno = [5100,5120])
trigger2 = stateno = [1100,1160]
trigger2 = p2statetype = A
;trigger2 = (p2dist y < -25 - p2bodydist x - (enemynear,vel y*3)) || (( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) > -28)
trigger2 = p2dist y != [-20 ,20- ((enemynear,const(size.head.pos.y)) / ifelse(p2statetype=C,2,1)) ]
var(52) = 1101
ignorehitpause = 1

[State AI, Guard A]
type = ChangeState
triggerall = stateno != [120,159]
triggerall = var(59)> 0
triggerall = random < 214
;triggerall = random < (1*(var(55)*var(55)*var(55)))
triggerall = (StateType = A) && (Ctrl) && (EnemyNear, Facing != Facing)
;triggerall = ((time >= 7-var(55)) && (enemynear,time >= 14-(var(55)*2)))
trigger1 = (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
trigger1 = p2dist y = [-20 ,20- (enemynear,const(size.head.pos.y)) ]
value = ifelse(command="holdback"||command="holdup"||command="holddown",100,132)

;===========================================================================
;NOAI
;---------------------------------------------------------------------------
[State -1, EnergyBall]
type = ChangeState
value = 1100
triggerall = command = "EnergyBall" || var(52) = 1100
triggerall = statetype = A
triggerall = numhelper(1110) = 0
trigger1 = ctrl
trigger2 = (stateno = 100) || (stateno = [200,219])
;trigger2 = movecontact

[State -1, SomerSault]
type = ChangeState
value = 1200
triggerall = command = "Somerflip" || var(52) = 1200
triggerall = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 100) || (stateno = [200,219])
;trigger2 = movecontact

[State -1, MachineBite]
type = ChangeState
value = 1000
triggerall = command = "MachineBite" || var(52) = 1000
triggerall = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 100) || (stateno = [200,219])
;trigger2 = movecontact

[State -1, Weak Bite]
type = ChangeState
value = 200
triggerall = command = "x" || var(52) = 200
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 100 && time)

[State -1, Strong Bite]
type = ChangeState
value = 210
triggerall = command = "a" || var(52) = 210
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 100 && time)
trigger3 = stateno = 200
trigger3 = time > 6 || movecontact

[State -1, Eat]
type = ChangeState
value = 220
triggerall = command = "y" || var(52) = 220
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = [200,210]) || stateno = 1000 || stateno = 1200
trigger2 = movecontact
trigger2 = power >= 1000
trigger3 = (stateno = 100 && time)
trigger4 = stateno = 200
trigger4 = time > 6 || movecontact


[State -1, Burp]
type = ChangeState
value = 195
triggerall = command = "start" || var(52) = 195
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = [200,219]
trigger2 = movecontact
trigger3 = (stateno = 100 && time)

[State -1, Dodge]
type = ChangeState
;triggerall = command = "dash"
triggerall = (command = "dash" && (command = "anydir" || stateno = 5)) || (var(52) = [100,109])
;triggerall = command = "anydir" || stateno = 5
trigger1 = statetype = A
trigger1 = Ctrl || stateno = 5
trigger2 = stateno = 200 || stateno = 210
trigger2 = movecontact
trigger2 = power >= 500
value = 100

[State -1, Guard]
type = ChangeState
triggerall = (command = "guard" && command != "anydir") || var(52) = 130
;trigger1 = command != "anydir"
trigger1 = statetype = A
trigger1 = Ctrl
value = 132

[State 0, ]
type = Helper
triggerall = command = "z" || var(52) = 500
trigger1 = alive
trigger1 = numhelper(500) = 0
trigger1 = roundstate = 2
trigger1 = power >= 1000
helpertype = normal
name = "Fooby"
ID = 500
pos = -50,-20
postype = back
facing = 1
stateno = 500
keyctrl = 0
ownpal = 1
ignorehitpause = 1
size.xscale = 0.5
size.yscale = 0.5

[State 0, ]
type = Helper
triggerall = command = "c" || var(52) = 510
trigger1 = alive
trigger1 = numhelper(510) = 0
trigger1 = roundstate = 2
trigger1 = power >= 1000
helpertype = normal
name = "Bomb"
ID = 510
pos = 10,0
postype = front
facing = -1
stateno = 510
keyctrl = 0
ownpal = 1
ignorehitpause = 1
size.xscale = 0.5
size.yscale = 0.5

